@@ -74,8 +74,6 @@ typedef enum
 
 # define N_EDIT_ACCOUNT_COLS	5
 
-#define PREFSBUFSIZE		1024
-
 PrefsAccount *cur_account;
 
 static GList *account_list = NULL;
@@ -1260,7 +1258,7 @@ static void account_list_view_add(PrefsAccount *ac_prefs)
 	gboolean getall;
 
 	name = ac_prefs->account_name;
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 	protocol = ac_prefs->protocol == A_POP3 ?
 		  (ac_prefs->ssl_pop == SSL_TUNNEL ?
 		   "POP3 (SSL)" :
