@@ -91,6 +91,9 @@ gboolean claws_init(int *argc, char ***argv)
 	if (claws_initialized)
 		return TRUE;
 
+#ifdef USE_GNUTLS
+	ssl_init();
+#endif
 	startup_dir = g_get_current_dir();
 
 	parse_parameter(argc, argv);
@@ -107,7 +110,7 @@ gboolean claws_init(int *argc, char ***argv)
 
 	/* backup if old rc file exists */
 	if (is_file_exist(RC_DIR)) {
-		if (rename(RC_DIR, RC_DIR ".bak") < 0) {
+		if (g_rename(RC_DIR, RC_DIR ".bak") < 0) {
 			FILE_OP_ERROR(RC_DIR, "rename");
 			return FALSE;
 		}
@@ -115,10 +118,6 @@ gboolean claws_init(int *argc, char ***argv)
 
 	srand((gint) time(NULL));
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
-	ssl_init();
-#endif
-
 	claws_initialized = TRUE;
 
 	return TRUE;
@@ -127,7 +126,7 @@ gboolean claws_init(int *argc, char ***argv)
 void claws_done(void)
 {
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 	ssl_done();
 #endif
 }
