@@ -1107,6 +1107,7 @@ static MimeInfo *find_encrypted_part(MimeInfo *rootinfo)
 gint messageview_show(MessageView *messageview, MsgInfo *msginfo,
 		      gboolean all_headers)
 {
+	gchar *text = NULL;
 	gchar *file;
 	MimeInfo *mimeinfo, *encinfo;
 	gchar *subject = NULL;
@@ -1186,8 +1187,15 @@ gint messageview_show(MessageView *messageview, MsgInfo *msginfo,
 	while ((encinfo = find_encrypted_part(mimeinfo)) != NULL) {
 		debug_print("decrypting message part\n");
 		if (privacy_mimeinfo_decrypt(encinfo) < 0) {
-			alertpanel_error(_("Couldn't decrypt: %s"),
-				privacy_get_error());
+			text = g_strdup_printf(_("Couldn't decrypt: %s"),
+					       privacy_get_error());
+			noticeview_show(messageview->noticeview);
+			noticeview_set_icon(messageview->noticeview,
+					    STOCK_PIXMAP_NOTICE_WARN);
+			noticeview_set_text(messageview->noticeview, text);
+			gtk_widget_hide(messageview->noticeview->button);
+			gtk_widget_hide(messageview->noticeview->button2);
+			g_free(text);
 			break;
 		}
 	}
@@ -2032,13 +2040,13 @@ static void print_cb(GtkAction *action, gpointer data)
 
 #if !defined(USE_GNOMEPRINT) && !GTK_CHECK_VERSION(2,10,0)
 	cmdline = input_dialog(_("Print"),
-			       _("Enter the print command line:\n"
+			       _("Enter the print command-line:\n"
 				 "('%s' will be replaced with file name)"),
 			       prefs_common.print_cmd);
 	if (!cmdline) return;
 	if (!(p = strchr(cmdline, '%')) || *(p + 1) != 's' ||
 	    strchr(p + 2, '%')) {
-		alertpanel_error(_("Print command line is invalid:\n'%s'"),
+		alertpanel_error(_("Print command-line is invalid:\n'%s'"),
 				 cmdline);
 		g_free(cmdline);
 		return;
